UNIT FContest;

{$O+}
{$F+}

{ PLEASE NOTE!!  This file is included with the TR Logging Program as a
  reference document.  It is intended to show you the default values for
  the different contests supported by the program.

  Changing parameters in this file will have no effect on the operation
  of TR or POST.

  Most variable names are the same as their LOGCFG commands, but in
  some cases, they are slightly different. }

INTERFACE

USES LogDom, Tree, LogCW, LogWind, LogDupe, ZoneCont, Country9;

    FUNCTION FoundContest (CMD: Str80): BOOLEAN;


IMPLEMENTATION


PROCEDURE SetUpRSTQSONumberExchange;

    BEGIN
    CQExchange := '_~ %5NN #';
    ExchangeFunctionKeyMenu := 'F1-DE+Cl  F2-Ex  F3-RST  F4-NR  F5-Cl+Ex  F8-EE  F9-?  Alt-AskforHis';
    RepeatSearchAndPounceExchange := '5NN #';
    SearchAndPounceExchange := '~ %5NN #';
    SetCQMemoryString (CW, F3, '5NN #');
    SetExMemoryString (CW, F3, '5NN');
    SetExMemoryString (CW, F4, 'NR #');
    SetExMemoryString (CW, F5, '@ DE \ 5NN #');
    SetExMemoryString (CW, AltF3, 'RST?');
    SetExMemoryString (CW, AltF4, 'NR?');
    END;


PROCEDURE AddARRLSectionDomesticCountries;

    BEGIN
    AddDomesticCountry ('K');
    AddDomesticCountry ('VE');
    AddDomesticCountry ('KC6');
    AddDomesticCountry ('KG4');
    AddDomesticCountry ('KL');
    AddDomesticCountry ('KH0');
    AddDomesticCountry ('KH1');
    AddDomesticCountry ('KH2');
    AddDomesticCountry ('KH3');
    AddDomesticCountry ('KH4');
    AddDomesticCountry ('KH5');
    AddDomesticCountry ('KH6');
    AddDomesticCountry ('KH7');
    AddDomesticCountry ('KH8');
    AddDomesticCountry ('KH9');
    AddDomesticCountry ('KP1');
    AddDomesticCountry ('KP2');
    AddDomesticCountry ('KP3');
    AddDomesticCountry ('KP4');
    AddDomesticCountry ('KP5');
    END;



FUNCTION FoundContest (CMD: Str80): BOOLEAN;

VAR TempQTH: QTHRecord;

    BEGIN
    CountryTable.CountryMode := ARRLCountryMode;
    CountryTable.ZoneMode    := ITUZoneMode;

    FoundContest := False;

    CMD := UpperCase (CMD);

    IF CMD = 'ALL ASIAN' THEN
        BEGIN
        IF MyContinent = Asia THEN
            ActiveDXMult := ARRLDXCC
        ELSE
            ActivePrefixMult := Prefix;

        ActiveExchange := RSTAgeExchange;
        ActiveQSOPointMethod := AllAsianQSOPointMethod;
        ContestName := 'All Asian';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        FoundContest := True;
        END;

    IF CMD = 'ALL JA' THEN
        BEGIN
        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveExchange := RSTAllJAPrefectureAndPowerExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'All JA';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        FoundContest := True;
        END;

    IF CMD = 'ARCI' THEN
        BEGIN
        ActiveExchange := RSTPossibleDomesticQTHAndPower;
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult := ARRLDXCCWithNoUSACanadaKH6OrKL7;
        ActiveQSOPointMethod := ARCIQSOPointMethod;
        ContestName := 'ARCI QSO PARTY';
        DomesticQTHDataFileName := 'S50P12.DOM';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        FoundContest := True;

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KL');
        AddDomesticCountry ('KH6');
        END;

    IF CMD = 'ARI' THEN
        BEGIN
        ActiveExchange := RSTAndQSONumberOrDomesticQTHExchange;
        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveDXMult := ARRLDXCCWithNoIOrIS0;
        ActiveQSOPointMethod := ARIQSOPointMethod;
        ContestName := 'ARI International DX Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        AddDomesticCountry ('I');
        AddDomesticCountry ('IS0');
        END;

    IF CMD = 'ARRL 10' THEN
        BEGIN
        ActiveBand := Band10;
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult := ARRLDXCCWithNoUSACanadaKH6OrKL7;
        ActiveQSOPointMethod := ARRL10QSOPointMethod;
        ActiveExchange := RSTDomesticQTHOrQSONumberExchange;
        ContestName := 'ARRL Ten Meter Contest';
        DomesticQTHDataFileName := 'S50P13DC.DOM';
        MultByBand := False;
        MultByMode := True;
        MultipleBandsEnabled := False;
        QSOByBand := False;
        QSOByMode := True;
        FoundContest := True;

        AddDomesticCountry ('K');     { Doesn't really get used }
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KL');
        AddDomesticCountry ('KH6');
        END;


    IF CMD = 'ARRL 160' THEN
        BEGIN
        IF (MyCountry = 'K') OR
           (MyCountry = 'VE') THEN
            BEGIN
            ActiveExchange := RSTDomesticOrDXQTHExchange;
            ActiveDXMult   := ARRLDXCCWithNoARRLSections;
            END
        ELSE
            ActiveExchange := RSTDomesticQTHExchange;

        ActiveDomesticMult := DomesticFile;
        ActiveQSOPointMethod := ARRL160QSOPointMethod;
        ContestName := 'ARRL 160 Contest';
        DomesticQTHDataFileName := 'ARRLSECT.DOM';
        MultByBand := False;
        MultByMode := False;
        QSOByBand  := False;
        QSOByMode  := False;
        FoundContest := True;

        AddARRLSectionDomesticCountries;
        END;


    IF CMD = 'ARRL DX' THEN
        BEGIN
        IF MyCall = '' THEN
            BEGIN
            Write ('Please put valid MY CALL statement before the CONTEST statement.  Thanks!');
            Exit;
            END;

        IF (MyCountry = 'K') OR
           (MyCountry = 'VE') THEN
            BEGIN
            ActiveExchange := RSTPowerExchange;
            ActiveDXMult   := ARRLDXCCWithNoUSAOrCanada;
            END
        ELSE
            BEGIN
            ActiveDomesticMult := DomesticFile;
            DomesticQTHDataFileName := 'S48P13DC.DOM';
            ActiveExchange     := RSTDomesticQTHExchange;
            END;

        ActiveQSOPointMethod := ARRLDXQSOPointMethod;
        ContestName := 'ARRL DX Test';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        FoundContest := True;

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        END;

    IF CMD = 'ARRL VHF QSO' THEN
        BEGIN
        ActiveBand := Band6;
        ActiveDomesticMult := GridSquares;
        ActiveExchange := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := ARRLVHFQSOPointMethod;
        ContestName := 'VHF QSO Party';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        HFBandEnable := False;
        VHFBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'ARRL VHF SS' THEN
        BEGIN
        ActiveBand := Band6;
        ActiveDomesticMult := GridSquares;
        ActiveExchange := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := ARRLVHFSSPointMethod;
        ContestName := 'ARRL VHF SWEEPSTAKES';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        HFBandEnable := False;
        VHFBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'CAL QSO PARTY' THEN
        BEGIN
        IF UpperCase (Copy (MyState, 1, 2)) = 'CA' THEN
            BEGIN
            ActiveDomesticMult := DomesticFile;
            DomesticQTHDataFileName := 'CALQSOW6.DOM';
            ActiveExchange := QSONumberDomesticOrDXQTHExchange;
            CQP := True;
            END
        ELSE
            BEGIN
            ActiveDomesticMult := DomesticFile;
            DomesticQTHDataFileName := 'CALCTY.DOM';
            ActiveExchange := QSONumberDomesticQTHExchange;
            END;

        ActiveQSOPointMethod := TwoPhoneThreeCW;
        ContestName := 'California QSO Party';
        MultByBand := False;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KH6');
        AddDomesticCountry ('KL');
        END;

    IF CMD = 'COUNTY HUNTER' THEN
        BEGIN
        ActiveExchange := RSTQTHExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'Country Hunting';
        FoundContest := True;
        END;

    IF CMD = 'CQ 160' THEN
        BEGIN
        CountryTable.CountryMode := CQCountryMode;
        CountryTable.ZoneMode    := CQZoneMode;

        ActiveBand             := Band160;
        ActiveDomesticMult     := DomesticFile;
        ActiveDXMult           := CQDXCCWithNoUSAOrCanada;
        ActiveExchange         := RSTDomesticOrDXQTHExchange;
        ActiveQSOPointMethod   := CQ160QSOPointMethod;
        ContestName := 'CQ 160 Contest';
        MultByBand := False;
        MultByMode := False;
        MultipleBandsEnabled := False;
        QSOByBand  := False;
        QSOByMode  := False;
        DomesticQTHDataFileName := 'S48P13DC.DOM';
        FoundContest := True;

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        END;

    IF CMD = 'CQ M' THEN
        BEGIN
        ActiveDXMult := ARRLDXCC;
        ActiveExchange := RSTQSONumberExchange;
        ActiveQSOPointMethod := CQMQSOPointMethod;
        ContestName := 'CQ M Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        END;

    IF CMD = 'CQ VHF' THEN
        BEGIN
        ActiveBand := Band6;
        ActiveDomesticMult := GridSquares;
        ActiveExchange := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := CQVHFQSOPointMethod;
        ContestName := 'CQ WORLD WIDE VHF Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        HFBandEnable := False;
        VHFBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'CQ WPX' THEN
        BEGIN
        CountryTable.CountryMode := CQCountryMode;
        CountryTable.ZoneMode    := CQZoneMode;

        ActiveExchange := RSTQSONumberExchange;
        ActivePrefixMult := Prefix;
        ActiveQSOPointMethod := CQWPXQSOPointMethod;
        ContestName := 'CQ WPX Contest';
        MultByBand := False;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        END;



    IF CMD = 'CQ WW' THEN
        BEGIN
        CountryTable.CountryMode := CQCountryMode;
        CountryTable.ZoneMode    := CQZoneMode;

        ActiveDXMult := CQDXCC;
        ActiveExchange := RSTZoneExchange;
        ActiveInitialExchange := ZoneInitialExchange;
        ActiveQSOPointMethod := CQWWQSOPointMethod;
        ActiveZoneMult := CQZones;
        ContestName := 'CQ WW Contest';
        CQExchange := '5NN ' + MyZone;
        ExchangeFunctionKeyMenu := 'F1-DE Call  F2-RST#  F3-RST  F4-Zone  Alt-AskForHis  F5-Cl+Ex  AltF10-CfmCl';
        SetCQMemoryString (CW, F3, '5NN ' + MyZone);
        SetEXMemoryString (CW, F3, '5NN');
        SetExMemoryString (CW, F4, MyZone);
        SetExMemoryString (CW, F5, '@ DE \ 5NN ' + MyZone);
        SetExMemoryString (CW, AltF3, 'RST?');
        SetExMemoryString (CW, AltF4, 'NR?');
        RepeatSearchAndPounceExchange := '5NN ' + MyZone;
        SearchAndPounceExchange := '~ %5NN ' + MyZone;
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        FoundContest := True;
        END;

    IF (CMD = 'REGION ONE FIELD DAY') OR (CMD = 'REGION 1 FIELD DAY') THEN
        BEGIN
        ActiveDXMult := CQDXCC;
        ActiveExchange := RSTQSONumberExchange;
        ActiveQSOPointMethod := EuropeanFieldDayQSOPointMethod;
        ContestName := 'Region One Field Day';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'EUROPEAN HFC' THEN
        BEGIN
        ActiveExchange := RSTZoneExchange;
        ActiveInitialExchange := ZoneInitialExchange;
        ActiveQSOPointMethod := OnePhoneTwoCW;
        ActiveZoneMult := BranchZones;
        ContestName := 'European HF Championship';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;
        END;

    IF CMD = 'KVP' THEN
        BEGIN
        ActiveBand := Band80;
        ActiveExchange := RSTZoneExchange;
        ActiveInitialExchange := ZoneInitialExchange;
        ActiveQSOPointMethod := OnePhoneTwoCW;
        ActiveZoneMult := BranchZones;
        ContestName := 'KV Prvenstvo ZRS';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'EUROPEAN VHF' THEN
        BEGIN
        ActiveBand := Band6;
        ActiveExchange := RSTQSONumberAndGridSquareExchange;
        ActiveQSOPointMethod := EuropeanVHFQSOPointMethod;
        ContestName := 'EUROPEAN VHF CONTEST';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        HFBandEnable := False;
        VHFBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'FIELD DAY' THEN
        BEGIN
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult       := ARRLDXCCWithNoARRLSections;
        ActiveExchange := ClassDomesticOrDXQTHExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'Field Day';
        DigitalModeEnable := True;
        QSOByBand := True;
        QSOByMode := True;
        DomesticQTHDataFileName := 'ARRLSECT.DOM';
        VHFBandsEnabled := True;
        WARCBandsEnabled := True;

        SetCQMemoryString (CW, F1, 'CQ^FD \ \ FD');
        SetCQMemoryString (CW, F2, 'CQ^FD CQ^FD \ \ FD');

        CQExchange  := ' 2A OR';
        SearchAndPounceExchange := '2A OR';
        QSLMessage  := '73 \ FD';

        FoundContest := True;

        AddARRLSectionDomesticCountries;
        END;

    IF CMD = 'GENERAL QSO' THEN
        BEGIN
        ActiveExchange := RSTNameAndQTHExchange;
        ActiveInitialExchange := NameQTHInitialExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        AutoDupeEnableCQ := False;
        AutoDupeEnableSAndP := False;
        ContestName := 'General QSOs';
        QSOByBand := True;
        QSOByMode := True;
        WARCBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'GRID LOC' THEN
        BEGIN
        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveInitialExchange := NameInitialExchange;
        ActiveExchange := NameAndPossibleGridSquareExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'Grid Loc Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'HA DX' THEN
        BEGIN
        ActiveDomesticMult := DomesticFile;
        ActiveExchange := RSTQSONumberAndPossibleDomesticQTHExchange;
        ActiveQSOPointMethod := HADXQSOPointMethod;
        ContestName := 'HA-DX Contest';
        DomesticQTHDataFileName := 'HUNGARY.DOM';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        AddDomesticCountry ('HA');
        END;

    IF CMD = 'HELVETIA' THEN
        BEGIN
        ActiveDomesticMult := DomesticFile;

        IF MyCountry = 'HB' THEN
            ActiveDXMult := ARRLDXCC
        ELSE
            AddDomesticCountry ('HB');

        ActiveExchange := RSTQSONumberAndPossibleDomesticQTHExchange;
        ActiveQSOPointMethod := HelvetiaQSOPointMethod;
        ContestName := 'Helvetia Contest';
        DomesticQTHDataFileName := 'SWISS.DOM';
        ExchangeFunctionKeyMenu := 'F1-DE Call  F2-RST #  F3-RST  F4-#  Alt-AskForHis  AltF5-QTH?';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        SetExMemoryString (CW, AltF5, 'QTH?');
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        END;

    IF (CMD = 'IARU') OR (CMD = 'WRTC') OR (CMD = 'CROATIAN') THEN
        BEGIN
        LocateCall (MyCall, TempQTH, True);
        Str (CountryTable.GetZone (MyCall),  MyZone);

        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveExchange := RSTZoneOrSocietyExchange;
        ActiveInitialExchange := ZoneInitialExchange;
        ActiveQSOPointMethod := IARUQSOPointMethod;
        ActiveZoneMult := ITUZones;
        ContestName := 'IARU Radiosport';
        CQExchange := ' $5NN ' + MyZone;
        ExchangeFunctionKeyMenu := 'F1-DE  F2-Ex  F3-RST  F4-Zone F5-Cl+Ex F8-EE  F9-?  Alt = Ask for his';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := True;
        RepeatSearchAndPounceExchange := '5NN ' + MyZone;
        SearchAndPounceExchange := '~ %5NN ' + MyZone;

        SetCQMemoryString (CW, F3, '5NN ' + MyZone);

        SetExMemoryString (CW, F3, '5NN');
        SetExMemoryString (CW, F4, MyZone);
        SetExMemoryString (CW, F5, '@ DE \ 5NN ' + MyZone);

        SetExMemoryString (CW, AltF3, 'RST?');
        SetExMemoryString (CW, AltF4, 'ZONE?');

        FoundContest := True;

        LocateCall (MyCall, TempQTH, True);
        MyCountry     := CountryTable.GetCountryID (TempQTH.Country);
        MyContinent   := TempQTH.Continent;
        Str (TempQTH.Zone,  MyZone);

        IF CMD = 'WRTC' THEN
            BEGIN
            ActiveDXMult := ARRLDXCC;
            ActiveQSOPointMethod := OnePhoneTwoCW;
            ContestName := 'IARU RADIOSPORT FOR WRTC';
            ActiveBand := Band40;
            END;

        IF CMD = 'CROATIAN' THEN
            BEGIN
            ActiveQSOPointMethod := CroatianQSOPointMethod;
            ActiveDomesticMult := NoDomesticMults;
            ActiveDXMult := CQDXCC;
            ActiveZoneMult := NoZoneMults;
            ContestName := 'Croatian';
            END;

        END;

    IF CMD = 'INTERNET SIX' THEN
        BEGIN
        ActiveBand := Band6;
        ActiveDomesticMult := GridSquares;
        ActiveDXMult       := CQDXCC;
        ActiveExchange := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := InternetSixQSOPointMethod;
        ContestName := 'Internet 6m Contest';
        MultByBand := False;
        MultByMode := False;
        QSOByBand := False;
        QSOByMode := False;
        HFBandEnable := False;
        VHFBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'INTERNET SPRINT' THEN
        BEGIN
        ActiveBand := Band20;
        AutoDupeEnableCQ    := False;
        AutoDupeEnableSAndP := False;
        ActiveExchange := QSONumberNameDomesticOrDXQTHExchange;
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult := NorthAmericanARRLDXCCWithNoUSACanadaOrkL7;
        ActiveInitialExchange := NoInitialExchange;
        ActiveQSOPointMethod := AlwaysOnePointPerQSO;
        ContestName := 'Internet SprINT';
        DomesticQTHDataFileName := 'S49P13.DOM';
        ExchangeMemoryEnable := False;
        MultByBand := False;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        SprintQSYRule := True;
        VisibleDupeSheetEnable := False;
        FoundContest := True;

        SearchAndPounceExchange := '@ # ( ORE \';
        RepeatSearchAndPounceExchange := '@ # ( ORE';
        CQExchange := ' \ # ( ORE';
        QSLMessage := 'EE';

        SetCQMemoryString (CW, F1,  'INT \');
        SetCQMemoryString (CW, F2, 'CQ^INT \ \ INT');

        SetCQMemoryString (CW, F5, '?');
        SetCQMemoryString (CW, F6, 'INT \');
        SetCQMemoryString (CW, F7, 'CQ^INT \ \ INT');
        SetCQMemoryString (CW, F8, 'CQ^INT CQ^INT \ \ INT');

        SetEXMemoryString (CW, F7, 'CQ^INT \ \ INT');
        SetEXMemoryString (CW, F8, 'CQ^INT CQ^INT \ \ INT');
        SetEXMemoryString (CW, F3, '#');
        SetEXMemoryString (CW, F4, '(');
        SetEXMemoryString (CW, F5, 'ORE');
        SetEXMemoryString (CW, F6, '@ \ # ( ORE');
        SetEXMemorySTring (CW, AltF3, 'NR?');
        SetEXMemorySTring (CW, AltF4, 'NAME?');
        SetEXMemorySTring (CW, AltF5, 'QTH?');

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KL');
        END;

    IF CMD = 'IOTA' THEN
        BEGIN
        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveExchange := RSTQSONumberAndPossibleDomesticQTHExchange;
        ActiveQSOPointMethod := IOTAQSOPointMethod;
        ContestName := 'RSGB IOTA Contest';
        MultByBand := True;
        MultByMode := True;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;
        END;

    IF (CMD = 'JA INTERNATIONAL DX') OR (CMD = 'JIDX') THEN
        BEGIN
        IF MyCountry = 'JA' THEN
            BEGIN
            ActiveDXMult := ARRLDXCC;
            ActiveInitialExchange := ZoneInitialExchange;
            ActiveZoneMult := CQZones;
            END
        ELSE
            ActiveZoneMult := JAPrefectures;

        ActiveExchange := RSTZoneExchange;
        ActiveQSOPointMethod := JapanInternationalDXQSOPointMethod;
        ContestName := 'Japan International DX Test';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        CountryTable.ZoneMode := CQZoneMode;
        FoundContest := True;
        END;

    IF CMD = 'KCJ' THEN
        BEGIN
        ActiveDomesticMult := DomesticFile;

        IF (MyCountry = 'JA') OR
           (MyCountry = 'JD1') THEN
            DomesticQTHDataFileName := 'JAPREFCT.DOM'
        ELSE
            DomesticQTHDataFileName := 'JAPREF.DOM';

        ActiveExchange := RSTDomesticQTHExchange;
        ActiveMode := CW;
        ActiveQSOPointMethod := KCJQSOPointMethod;
        ContestName := 'KCJ Single Op Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;

        ExchangeFunctionKeyMenu := 'F1-DE  F2-Ex  F3-RST  F4-QTH  F5-Cl+Ex  F8-EE  F9-?  Alt = Ask for his';

        CQExchange := '_~ %5NN ' + CountryTable.GetContinentName (MyContinent);
        QSLMessage := '73 \ KCJ';
        QSOBeforeMessage := '_SRI QSO B4 73 \ KCJ';
        QuickQSLMessage1 := 'QSL TU EE';
        QuickQSLMessage2 := 'TU EE';
        RepeatSearchAndPounceExchange := '5NN ' + CountryTable.GetContinentName (MyContinent);
        SearchAndPounceExchange := '~ %5NN ' + CountryTable.GetContinentName (MyContinent);
        SetCQMemoryString (CW, F1, 'CQTEST CQKCJ  \ \ KCJ');
        SetCQMemoryString (CW, F2, 'CQKCJ CQTEST CQKCJ  \  \  \ KCJ');

        SetCQMemoryString (CW, F3, '5NN ' + MyZone);
        SetExMemoryString (CW, F3, '5NN');
        SetExMemoryString (CW, F4, CountryTable.GetContinentName (MyContinent));
        SetExMemoryString (CW, F5, '@ DE \ 5NN ' + CountryTable.GetContinentName (MyContinent));
        SetExMemoryString (CW, AltF3, 'RST?');
        SetExMemoryString (CW, AltF4, 'QTH?');
        FoundContest := True;
        END;



    IF CMD = 'NA QSO' THEN
        BEGIN
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult := NorthAmericanARRLDXCCWithNoUSACanadaOrkL7;
        ActiveExchange := NameAndDomesticOrDXQTHExchange;
        ActiveInitialExchange := NameInitialExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'North American QSO Party';
        DomesticQTHDataFileName := 'S50P12.DOM';

        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        FoundContest := True;

        CQExchange := ' ' + MyName + ' ' + MyState;
        QSLMessage := '73 \ NA>';
        QuickQSLMessage1 := 'TU';
        QSOBeforeMessage := ' QSO B4 \ NA';
        SearchAndPounceExchange := MyName + ' ' + MyState;
        CorrectedCallMessage := '} R';

        SetCQMemoryString (CW, F1, 'CQ^NA \ \ NA>');
        SetCQMemoryString (CW, F2, 'CQ^NA CQ^NA \ \ NA>');

        SetCQMemoryString (CW, F5,  '?');
        SetCQMemoryString (CW, F6,  'NA \ NA');
        SetCQMemoryString (CW, F7,  'CQ^NA \ \ NA');
        SetCQMemoryString (CW, F8,  'CQ^NA CQ^NA \ \ NA');

        SetCQMemoryString (CW, AltF1,  'NA \ \ NA');
        SetCQMemoryString (CW, AltF1,  'NA \ \ NA');

        SetExMemoryString (CW, F3, MyName);
        SetExMemoryString (CW, F4, MyState);
        SetExMemoryString (CW, F5, '@ DE \ ' + MyName + ' ' + MyState);
        SetExMemoryString (CW, AltF3, 'NAME?');
        SetExMemoryString (CW, AltF4, 'QTH?');

        SetExMemoryString (CW, F7,  'CQ^NA \ \ NA');
        SetExMemoryString (CW, F8,  'CQ^NA CQ^NA \ \ NA');

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KL');
        AddDomesticCountry ('KH6');
        END;

    IF CMD = 'NRAU' THEN
        BEGIN
        ActiveBand := Band80;
        ActiveDomesticMult := DomesticFile;
        DomesticQTHDataFileName := 'NRAU.DOM';
        ActiveExchange := RSTQSONumberAndDomesticQTHExchange;
        ActiveQSOPointMethod := TwoPointsPerQSO;
        ContestName := 'NRAU Contest';
        MultByBand := True;
        MultByMode := True;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;
        END;

    IF CMD = 'NZ FIELD DAY' THEN
        BEGIN
        ActiveExchange := NZFieldDayExchange;
        ActiveQSOPointMethod := NZFieldDayQSOPointMethod;
        ActiveZoneMult := BranchZones;
        ContestName := 'New Zealand Field Day Contest';
        MultByBand := True;
        MultByMode := True;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'OK DX' THEN
        BEGIN
        CountryTable.CountryMode := CQCountryMode;
        CountryTable.ZoneMode    := CQZoneMode;

        ActiveExchange := RSTAndQSONumberOrDomesticQTHExchange;
        ActiveQSOPointMethod := OKDXQSOPointMethod;
        AddDomesticCountry ('OK');
        AddDomesticCountry ('OM');
        ContestName := 'OK/OM DX Contest';

        IF (MyCountry <> 'OK') AND (MyCountry <> 'OM') THEN
            BEGIN
            ActiveDomesticMult := DomesticFile;
            DomesticQTHDataFileName := 'OKOM.DOM';
            MultByBand := True;
            MultByMode := True;
            SetUpRSTQSONumberExchange;
            END
        ELSE
            BEGIN
            ActivePrefixMult := Prefix;
            MultByBand := False;
            MultByMode := False;
            END;

        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'PACC' THEN
        BEGIN
        ActiveDomesticMult   := WYSIWYGDomestic;
        ActiveExchange       := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'PACC Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        FoundContest := True;
        END;

    IF CMD = 'QCWA' THEN
        BEGIN
        ActiveExchange := QSONumberNameChapterAndQTHExchange;
        ActiveQSOPointMethod := OnePhoneTwoCW;
        AddDomesticCountry ('K');
        AddDomesticCountry ('KH6');
        AddDomesticCountry ('KL');

        ContestName := 'QCWA QSO Party';
        MultByBand := False;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'QCWA GOLDEN' THEN
        BEGIN
        ActiveExchange := CheckAndChapterOrQTHExchange;
        ActiveQSOPointMethod := OnePointPerQSO;

        ContestName := 'QCWA Golden Anniversary';
        MultByBand := False;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'RAC' THEN
        BEGIN
        ActiveExchange := RSTAndQSONumberOrDomesticQTHExchange;
        ActiveDomesticMult := DomesticFile;
        DomesticQTHDataFileName := 'P12.DOM';
        ActiveQSOPointMethod := RACQSOPointMethod;
        AddDomesticCountry ('VE');
        AddDomesticCountry ('CY0');
        AddDomesticCountry ('CY9');
        ContestName := 'RAC Winter Contest';
        MultByBand := True;
        MultByMode := True;
        QSOByBand := True;
        QSOByMode := True;
        VHFBandsEnabled := True;
        FoundContest := True;
        END;

    IF CMD = 'RUSSIAN DX' THEN
        BEGIN
        ActiveExchange := RSTQSONumberAndPossibleDomesticQTHExchange;
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult := ARRLDXCC;
        AddDomesticCountry ('UA');
        DomesticQTHDataFileName := 'RUSSIAN.DOM';
        ActiveQSOPointMethod := RussianDXQSOPointMethod;
        ContestName := 'Russian DX Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;
        END;

    IF (CMD = 'SCANDINAVIAN') OR (CMD = 'SAC') THEN
        BEGIN
        ActiveExchange := RSTQSONumberExchange;

        IF ScandinavianCountry (MyCountry) THEN
            ActiveDXMult := ARRLDXCC
        ELSE
            ActivePrefixMult := SACDistricts;

        ActiveQSOPointMethod := ScandinavianQSOPointMethod;
        ContestName := 'Scandinavian Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := False;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        END;

    IF CMD = 'SOUTH AMERICAN WW' THEN
        BEGIN
        ActiveExchange := RSTAndContinentExchange;

        IF MyContinent = SouthAmerica THEN
            ActivePrefixMult := NonSouthAmericanPrefixes
        ELSE
            ActivePrefixMult := SouthAmericanPrefixes;

        ActiveQSOPointMethod := SouthAmericanWWQSOPointMethod;
        ContestName := 'South American WW';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        END;

    IF CMD = 'SP DX' THEN
        BEGIN
        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveExchange := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := ThreePointsPerQSO;
        ContestName := 'SP-DX Contest';
        MultByBand := True;
        MultByMode := True;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;
        AddDomesticCountry ('SP');
        END;

    IF CMD = 'SPRINT' THEN
        BEGIN
        ActiveBand := Band20;
        ActiveExchange := QSONumberNameDomesticOrDXQTHExchange;
        ActiveDomesticMult := DomesticFile;
        ActiveDXMult := NorthAmericanARRLDXCCWithNoUSACanadaOrkL7;
        ActiveInitialExchange := NameQTHInitialExchange;
        ActiveQSOPointMethod := OnePointPerQSO;
        ContestName := 'North American Sprint';
        DomesticQTHDataFileName := 'S49P8.DOM';

        SetCQMemoryString (CW, AltF1,  'NA \ NA');

        CQExchange := '^\ # ' + MyName + ' ' + MyState;
        QSLMessage := 'TU';
        QuickQSLMessage1 := 'EE';
        QSOBeforeMessage := 'B4 \ NA';
        SearchAndPounceExchange := '@ # ' + MyName + ' ' + MyState + ' \';
        RepeatSearchAndPounceExchange := '# ' + MyName + ' ' + MyState;
        CorrectedCallMessage := '} R';

        SetCQMemoryString (CW, F1,  'NA \');
        SetCQMemoryString (CW, F2,  'CQ^NA CQ^NA \ \ NA');
        SetCQMemoryString (CW, F5,  '?');
        SetCQMemoryString (CW, F6,  'NA \ NA');
        SetCQMemoryString (CW, F7,  'CQ^NA \ \ NA');
        SetCQMemoryString (CW, F8,  'CQ^NA CQ^NA \ \ NA');
        SetCQMemoryString (CW, AltF1,  'NA \ \ NA');

        SetExMemoryString (CW, F3, 'NR #');
        SetExMemoryString (CW, F4, MyName);
        SetExMemoryString (CW, F5, MyState);
        SetExMemoryString (CW, F6, '@ \ NR^# ' + MyName + ' ' + MyState);
        SetExMemoryString (CW, F7,  'CQ^NA \ \ NA');
        SetExMemoryString (CW, F8,  'CQ^NA CQ^NA \ \ NA');
        SetExMemoryString (CW, AltF3, 'NR?');
        SetExMemoryString (CW, AltF4, 'NAME?');
        SetExMemoryString (CW, AltF5, 'QTH?');

        MultByBand := False;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        SprintQSYRule := True;
        VisibleDupeSheetEnable := True;
        FoundContest := True;

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KL');
        END;

    IF CMD = 'STEW PERRY' THEN
        BEGIN
        ActiveExchange := RSTAndOrGridExchange;
        ActiveQSOPointMethod := StewPerryQSOPointMethod;
        ContestName := 'STEW PERRY TOPBAND CHALLENGE';
        MultByBand := False;
        MultByMode := False;
        QSOByBand  := False;
        QSOByMode  := False;
        FoundContest := True;
        END;

    IF CMD = 'SWEEPSTAKES' THEN
        BEGIN
        ActiveDomesticMult := DomesticFile;
        ActiveExchange := QSONumberPrecedenceCheckDomesticQTHExchange;
        ActiveInitialExchange := CheckSectionInitialExchange;
        ActiveQSOPointMethod := TwoPointsPerQSO;
        CallsignUpdateEnable := True;
        ContestName := 'ARRL Sweepstakes';
        DomesticQTHDataFileName := 'ARRLSECT.DOM';
        MultByBand := False;
        MultByMode := False;
        QSOByBand  := False;
        QSOByMode  := True;
        FoundContest := True;

        AddARRLSectionDomesticCountries;
        END;

    IF CMD = 'TEN TEN' THEN
        BEGIN
        ActivePrefixMult := Prefix;
        ActiveExchange := NameQTHAndPossibleTenTenNumber;
        ActiveQSOPointMethod := TenTenQSOPointMethod;
        ContestName := 'Ten Ten QSO Party';
        MultByBand := False;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := True;
        FoundContest := True;
        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KH6');
        AddDomesticCountry ('KL');
        END;

    IF CMD = 'TEXAS QSO PARTY' THEN
        BEGIN
        IF (UpperCase (Copy (MyState, 1, 3)) = 'TEX') OR (UpperCase (Copy (MyState, 1, 2)) = 'TX') THEN
            BEGIN
            ActiveDomesticMult := DomesticFile;
            ActiveDXMult       := ARRLDXCCWithNoUSACanadaKH6OrKL7;
            DomesticQTHDataFileName := 'TEXASTX.DOM';
            ActiveExchange := RSTDomesticOrDXQTHExchange;
            CQP := True;
            END
        ELSE
            BEGIN
            ActiveDomesticMult := DomesticFile;
            DomesticQTHDataFileName := 'TEXAS.DOM';
            ActiveExchange := RSTDomesticQTHExchange;
            END;

        ActiveQSOPointMethod := TwoPhoneThreeCW;
        ContestName := 'Texas QSO Party';
        MultByBand := False;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;

        AddDomesticCountry ('K');
        AddDomesticCountry ('VE');
        AddDomesticCountry ('KH6');
        AddDomesticCountry ('KL');
        END;



    IF CMD = 'TOEC' THEN
        BEGIN
        ActiveDomesticMult := GridFields;
        ActiveExchange := RSTDomesticQTHExchange;
        ActiveQSOPointMethod := TOECQSOPointMethod;
        ContestName := 'TOEC WW GRID CONTEST';
        MultByBand := True;
        MultByMode := False;
        QSOByBand := True;
        QSOByMode := False;
        FoundContest := True;
        END;

    IF CMD = 'VK ZL' THEN
        BEGIN
        ActivePrefixMult := Prefix;
        ActiveExchange := RSTQSONumberExchange;
        ActiveQSOPointMethod := VKZLQSOPointMethod;
        ContestName := 'VK ZL Oceania Contest';
        MultByBand := True;
        MultByMode := True;
        QSOByBand  := True;
        QSOByMode  := True;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        END;

    IF CMD = 'WAE' THEN
        BEGIN
        CountryTable.CountryMode := CQCountryMode;
        CountryTable.ZoneMode    := CQZoneMode;


        IF MyContinent = Europe THEN
            ActiveDXMult := CQNonEuropeanCountries
        ELSE
            ActiveDXMult := CQEuropeanCountries;

        ActiveBand := Band80;
        ActiveExchange := RSTQSONumberExchange;
        ActiveQSOPointMethod := WAEQSOPointMethod;
        ContestName := 'WAE Contest';
        ContactsPerPage := 40;
        MultByMode := False;
        MultByBand := True;
        QSOByBand  := True;
        QSOByMode  := False;
        QTCsEnabled := True;
        SetUpRSTQSONumberExchange;
        FoundContest := True;
        END;

    IF CMD = 'XMAS' THEN
        BEGIN
        ActiveExchange := RSTQSONumberAndRandomCharactersExchange;
        ActiveQSOPointMethod := TwoPointsPerQSO;
        ContestName := 'SSA X-MAS Contest';
        LeadingZeros := 3;
        MultByMode := False;
        MultByBand := True;
        QSOByBand  := True;
        QSOByMode  := False;
        FoundContest := True;
        END;

    IF CMD = 'YO DX' THEN
        BEGIN
        ActiveDomesticMult := WYSIWYGDomestic;
        ActiveExchange := RSTZoneAndPossibleDomesticQTHExchange;
        ActiveInitialExchange := ZoneInitialExchange;
        ActiveQSOPointMethod := YODXQSOPointMethod;
        ActiveZoneMult := ITUZones;
        ContestName := 'YO DX Contest';
        MultByBand := True;
        MultByMode := False;
        QSOByBand  := True;
        QSOByMode  := True;
        FoundContest := True;
        AddDomesticCountry ('YO');
        END;

    ContestTitle := GetYearString + ' ' + ContestName + ' ' + MyCall;
    Exit;
    END;




    BEGIN
    END.